@@ -146,7 +146,13 @@ void VerseKey::initstatics()
 			chaptmp += books[l1][l2].chapmax;
 		}
 	}
-	for (abbrevsCnt = 0; *abbrevs[abbrevsCnt].ab; abbrevsCnt++);
+
+        for (abbrevsCnt = 1; *abbrevs[abbrevsCnt].ab; abbrevsCnt++) {
+                if (strcmp(abbrevs[abbrevsCnt-1].ab, abbrevs[abbrevsCnt].ab) > 0) {
+			fprintf(stderr, "ERROR: canon.h abbrev misordered at entry: %s\n", abbrevs[abbrevsCnt].ab);
+			exit(-1);
+		}
+	}
 }
 
 
@@ -240,7 +246,8 @@ int VerseKey::getBookAbbrev(char *abbr)
 
 	if (abLen) {
 		min = 0;
-		max = abbrevsCnt - 1;
+//		max = abbrevsCnt - 1;
+		max = abbrevsCnt;
 		while(1) {
 			target = min + ((max - min) / 2);
 			diff = strncmp(abbr, abbrevs[target].ab, abLen);
@@ -882,10 +889,10 @@ char VerseKey::Book(char ibook)
 {
 	char retval = book;
 
-	if (ibook != MAXPOS(char)) {
-		book = ibook;
-		Normalize(1);
-	}
+	Chapter(1);
+	book = ibook;
+	Normalize(1);
+
 	return retval;
 }
 
@@ -904,10 +911,10 @@ int VerseKey::Chapter(int ichapter)
 {
 	int retval = chapter;
 
-	if (ichapter != MAXPOS(int)) {
-		chapter = ichapter;
-		Normalize(1);
-	}
+	Verse(1);
+	chapter = ichapter;
+	Normalize(1);
+
 	return retval;
 }
 
@@ -926,10 +933,9 @@ int VerseKey::Verse(int iverse)
 {
 	int retval = verse;
 
-	if (iverse != MAXPOS(int)) {
-		verse = iverse;
-		Normalize(1);
-	}
+	verse = iverse;
+	Normalize(1);
+
 	return retval;
 }
 
